pub struct PermissionList {
pub etag: Option<String>,
pub items: Option<Vec<Permission>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub self_link: Option<String>,
}Expand description
A list of permissions associated with a file.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list permissions (response)
Fields
etag: Option<String>The ETag of the list.
items: Option<Vec<Permission>>The list of permissions.
kind: Option<String>This is always drive#permissionList.
next_page_token: Option<String>The page token for the next page of permissions. This field will be absent if the end of the permissions list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results.
self_link: Option<String>A link back to this list.