[][src]Struct google_drive2::AppList

pub struct AppList {
    pub items: Option<Vec<App>>,
    pub kind: Option<String>,
    pub etag: Option<String>,
    pub self_link: Option<String>,
    pub default_app_ids: Option<Vec<String>>,
}

A list of third-party applications which the user has installed or given access to Google Drive.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

items: Option<Vec<App>>

The list of apps.

kind: Option<String>

This is always drive#appList.

etag: Option<String>

The ETag of the list.

self_link: Option<String>

A link back to this list.

default_app_ids: Option<Vec<String>>

List of app IDs that the user has specified to use by default. The list is in reverse-priority order (lowest to highest).