[][src]Struct google_drive2::ChildList

pub struct ChildList {
    pub next_page_token: Option<String>,
    pub kind: Option<String>,
    pub etag: Option<String>,
    pub items: Option<Vec<ChildReference>>,
    pub self_link: Option<String>,
    pub next_link: Option<String>,
}

A list of children of a file.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

next_page_token: Option<String>

The page token for the next page of children. This will be absent if the end of the children list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results.

kind: Option<String>

This is always drive#childList.

etag: Option<String>

The ETag of the list.

items: Option<Vec<ChildReference>>

The list of children. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched.

self_link: Option<String>

A link back to this list.

next_link: Option<String>

A link to the next page of children.