[][src]Struct google_drive2::ChildReference

pub struct ChildReference {
    pub kind: Option<String>,
    pub child_link: Option<String>,
    pub id: Option<String>,
    pub self_link: Option<String>,
}

A reference to a folder's child.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

kind: Option<String>

This is always drive#childReference.

child_link: Option<String>

A link to the child.

id: Option<String>

The ID of the child.

self_link: Option<String>

A link back to this reference.