Struct google_drive2::CommentContext
source · pub struct CommentContext {
pub type_: Option<String>,
pub value: Option<String>,
}Expand description
The context of the file which is being commented on.
This type is not used in any activity, and only used as part of another schema.
Fields
type_: Option<String>The MIME type of the context snippet.
value: Option<String>Data representation of the segment of the file being commented on. In the case of a text file for example, this would be the actual text that the comment is about.