[−][src]Struct google_drive2::CommentReplyList
A list of replies to a comment on a file in Google Drive.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list replies (response)
Fields
next_page_token: Option<String>The page token for the next page of replies. This will be absent if the end of the replies list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results.
items: Option<Vec<CommentReply>>The list of replies. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched.
kind: Option<String>This is always drive#commentReplyList.
self_link: Option<String>A link back to this list.
next_link: Option<String>A link to the next page of replies.