Struct google_drive2::FileList
source · pub struct FileList {
pub incomplete_search: Option<bool>,
pub next_page_token: Option<String>,
pub kind: Option<String>,
pub etag: Option<String>,
pub items: Option<Vec<File>>,
pub self_link: Option<String>,
pub next_link: Option<String>,
}Expand description
A list of files.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list files (response)
Fields
incomplete_search: Option<bool>Whether the search process was incomplete. If true, then some search results may be missing, since all documents were not searched. This may occur when searching multiple Team Drives with the “default,allTeamDrives” corpora, but all corpora could not be searched. When this happens, it is suggested that clients narrow their query by choosing a different corpus such as “default” or “teamDrive”.
next_page_token: Option<String>The page token for the next page of files. This will be absent if the end of the files list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results.
kind: Option<String>This is always drive#fileList.
etag: Option<String>The ETag of the list.
items: Option<Vec<File>>The list of files. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched.
self_link: Option<String>A link back to this list.
next_link: Option<String>A link to the next page of files.