Struct google_drive2::FileThumbnail
source · pub struct FileThumbnail {
pub mime_type: Option<String>,
pub image: Option<String>,
}Expand description
A thumbnail for the file. This will only be used if Drive cannot generate a standard thumbnail.
This type is not used in any activity, and only used as part of another schema.
Fields
mime_type: Option<String>The MIME type of the thumbnail.
image: Option<String>The URL-safe Base64 encoded bytes of the thumbnail image. It should conform to RFC 4648 section 5.