Struct google_drive2::GeneratedIds
source · pub struct GeneratedIds {
pub kind: Option<String>,
pub ids: Option<Vec<String>>,
pub space: Option<String>,
}Expand description
A list of generated IDs which can be provided in insert requests
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- generate ids files (response)
Fields
kind: Option<String>This is always drive#generatedIds
ids: Option<Vec<String>>The IDs generated for the requesting user in the specified space.
space: Option<String>The type of file that can be created with these IDs.