Struct google_drive2::User [−][src]
pub struct User {
pub picture: Option<UserPicture>,
pub kind: Option<String>,
pub is_authenticated_user: Option<bool>,
pub display_name: Option<String>,
pub email_address: Option<String>,
pub permission_id: Option<String>,
}Information about a Drive user.
This type is not used in any activity, and only used as part of another schema.
Fields
picture: Option<UserPicture>
The user's profile picture.
kind: Option<String>
This is always drive#user.
is_authenticated_user: Option<bool>
Whether this user is the same as the authenticated user for whom the request was made.
display_name: Option<String>
A plain text displayable name for this user.
email_address: Option<String>
The email address of the user.
permission_id: Option<String>
The user's ID as visible in the permissions collection.