Struct google_drive2::UserPicture
[−]
[src]
pub struct UserPicture {
pub url: Option<String>,
}The user's profile picture.
This type is not used in any activity, and only used as part of another schema.
Fields
url: Option<String>
A URL that points to a profile picture of this user.