google_drive21.0.4+20170512

NestedType

Implementors

In crate google_drive2

Trait google_drive2::NestedType

source ·
pub trait NestedType { }
Identifies types which are only used by other types internally. They have no special meaning, this trait just marks them for completeness.

Implementors

source

impl NestedType for AboutAdditionalRoleInfo

source

impl NestedType for AboutAdditionalRoleInfoRoleSets

source

impl NestedType for AboutExportFormats

source

impl NestedType for AboutFeatures

source

impl NestedType for AboutImportFormats

source

impl NestedType for AboutMaxUploadSizes

source

impl NestedType for AboutQuotaBytesByService

source

impl NestedType for AboutTeamDriveThemes

source

impl NestedType for AppIcons

source

impl NestedType for CommentContext

source

impl NestedType for FileCapabilities

source

impl NestedType for FileImageMediaMetadata

source

impl NestedType for FileImageMediaMetadataLocation

source

impl NestedType for FileIndexableText

source

impl NestedType for FileLabels

source

impl NestedType for FileThumbnail

source

impl NestedType for FileVideoMediaMetadata

source

impl NestedType for PermissionTeamDrivePermissionDetails

source

impl NestedType for TeamDriveBackgroundImageFile

source

impl NestedType for TeamDriveCapabilities

source

impl NestedType for UserPicture