Struct google_drive2::AboutFeatures
source · pub struct AboutFeatures {
pub feature_name: Option<String>,
pub feature_rate: Option<f64>,
}Expand description
List of additional features enabled on this account.
This type is not used in any activity, and only used as part of another schema.
Fields
feature_name: Option<String>The name of the feature.
feature_rate: Option<f64>The request limit rate for this feature, in queries per second.