Struct google_drive2::FileCapabilities
source · pub struct FileCapabilities {Show 17 fields
pub can_read_revisions: Option<bool>,
pub can_untrash: Option<bool>,
pub can_copy: Option<bool>,
pub can_move_item_into_team_drive: Option<bool>,
pub can_comment: Option<bool>,
pub can_list_children: Option<bool>,
pub can_rename: Option<bool>,
pub can_trash: Option<bool>,
pub can_delete: Option<bool>,
pub can_move_team_drive_item: Option<bool>,
pub can_add_children: Option<bool>,
pub can_change_restricted_download: Option<bool>,
pub can_share: Option<bool>,
pub can_download: Option<bool>,
pub can_remove_children: Option<bool>,
pub can_read_team_drive: Option<bool>,
pub can_edit: Option<bool>,
}Expand description
Capabilities the current user has on this file. Each capability corresponds to a fine-grained action that a user may take.
This type is not used in any activity, and only used as part of another schema.
Fields
can_read_revisions: Option<bool>Whether the current user can read the revisions resource of this file. For a Team Drive item, whether revisions of non-folder descendants of this item, or this item itself if it is not a folder, can be read.
can_untrash: Option<bool>Whether the current user can restore this file from trash.
can_copy: Option<bool>Whether the current user can copy this file. For a Team Drive item, whether the current user can copy non-folder descendants of this item, or this item itself if it is not a folder.
can_move_item_into_team_drive: Option<bool>Whether the current user can move this item into a Team Drive. If the item is in a Team Drive, this field is equivalent to canMoveTeamDriveItem.
can_comment: Option<bool>Whether the current user can comment on this file.
can_list_children: Option<bool>Whether the current user can list the children of this folder. This is always false when the item is not a folder.
can_rename: Option<bool>Whether the current user can rename this file.
can_trash: Option<bool>Whether the current user can move this file to trash.
can_delete: Option<bool>Whether the current user can delete this file.
can_move_team_drive_item: Option<bool>Whether the current user can move this Team Drive item by changing its parent. Note that a request to change the parent for this item may still fail depending on the new parent that is being added. Only populated for Team Drive files.
can_add_children: Option<bool>Whether the current user can add children to this folder. This is always false when the item is not a folder.
can_change_restricted_download: Option<bool>Whether the current user can change the restricted download label of this file.
Whether the current user can modify the sharing settings for this file.
can_download: Option<bool>Whether the current user can download this file.
can_remove_children: Option<bool>Whether the current user can remove children from this folder. This is always false when the item is not a folder.
can_read_team_drive: Option<bool>Whether the current user can read the Team Drive to which this file belongs. Only populated for Team Drive files.
can_edit: Option<bool>Whether the current user can edit this file.