Struct google_drive2::FileLabels
source · pub struct FileLabels {
pub starred: Option<bool>,
pub viewed: Option<bool>,
pub restricted: Option<bool>,
pub hidden: Option<bool>,
pub modified: Option<bool>,
pub trashed: Option<bool>,
}Expand description
A group of labels for the file.
This type is not used in any activity, and only used as part of another schema.
Fields
starred: Option<bool>Whether this file is starred by the user.
viewed: Option<bool>Whether this file has been viewed by this user.
restricted: Option<bool>Whether viewers and commenters are prevented from downloading, printing, and copying this file.
Deprecated.
modified: Option<bool>Whether the file has been modified by this user.
trashed: Option<bool>Whether this file has been trashed. This label applies to all users accessing the file; however, only owners are allowed to see and untrash files.