Struct google_drive2::ParentReference
source · pub struct ParentReference {
pub is_root: Option<bool>,
pub kind: Option<String>,
pub id: Option<String>,
pub self_link: Option<String>,
pub parent_link: Option<String>,
}Expand description
A reference to a file’s parent.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get parents (response)
- insert parents (request|response)
Fields
is_root: Option<bool>Whether or not the parent is the root folder.
kind: Option<String>This is always drive#parentReference.
id: Option<String>The ID of the parent.
self_link: Option<String>A link back to this reference.
parent_link: Option<String>A link to the parent.