Trait google_drive2::NestedType
[−]
[src]
pub trait NestedType { }Identifies types which are only used by other types internally. They have no special meaning, this trait just marks them for completeness.
Implementors
impl NestedType for FileThumbnailimpl NestedType for AboutAdditionalRoleInfoimpl NestedType for FileIndexableTextimpl NestedType for AboutAdditionalRoleInfoRoleSetsimpl NestedType for AboutImportFormatsimpl NestedType for AboutMaxUploadSizesimpl NestedType for FileLabelsimpl NestedType for AboutQuotaBytesByServiceimpl NestedType for FileImageMediaMetadataimpl NestedType for FileImageMediaMetadataLocationimpl NestedType for UserPictureimpl NestedType for AboutFeaturesimpl NestedType for AppIconsimpl NestedType for CommentContextimpl NestedType for FileVideoMediaMetadataimpl NestedType for AboutExportFormats